@@ -2,6 +2,7 @@ module Main where
 
 import MkstempSpec
 import LinksSpec
+import ProcessSpec
 
 import Test.Hspec
 
@@ -9,3 +10,4 @@ main :: IO ()
 main = hspec $ do
     mkstempSpec
     linksSpec
+    processSpec
